@@ -182,7 +182,12 @@ class EntityAggregate(object):
         assert(len(self._agg) > 0)
         agg_type = self._agg[0]
         assert(agg_type in ['+', '%'])
-        field_name = self._agg[1:]
+        field_path = self._agg[1:]
+        try:
+            alias, field_name = field_path.split('.')
+        except:
+            alias = None
+            field_name = field_path
         mult = 1 if self._asc else -1
         if self._agg == '+':
             counters = defaultdict(int)
@@ -194,9 +199,12 @@ class EntityAggregate(object):
             if field_name == '':
                 value = 1
             else:
-                entity = entity_cache.get(entity_id, self._graph._item_from_id(self._entity_kind, entity_id))
-                entity_cache[entity_id] = entity
-                value = getattr(entity, field_name, 0)
+                if alias is None:
+                    obj = entity = entity_cache.get(entity_id, self._graph._item_from_id(self._entity_kind, entity_id))
+                    entity_cache[entity_id] = entity
+                else:
+                    obj = self._entity_iterator._context[alias]
+                value = getattr(obj, field_name, 0)
             counters[entity_id] += value
             total += value
         if total and (agg_type == '%'):
@@ -265,7 +273,7 @@ class EntityIterator(object):
             self._neighbors_cache = {}
 
     def _iterate(self, on_item=False):
-        for item in filter_entities(self._graph, self._src_kind, self._id_iterator, self._filter_funcs, on_item):
+        for item in filter_entities(self._graph, self._src_kind, self._id_iterator, self._filter_funcs, on_item=on_item):
             yield item
         self._finalize()
 
@@ -810,14 +818,6 @@ class BaseGraph(GraphReadWrite):
             self._db_close()
             self._closed = True
 
-    def __getattribute__(self, attr):
-        try:
-            if object.__getattribute__(self, '_closed'):
-                raise GrapheekDataException('Graph is closed')
-        except AttributeError:
-            pass  # no _closed attribute -> no definitely not closed (not even open, in fact)
-        return object.__getattribute__(self, attr)
-
     def __initialize__(self):
         # "Rebuilding" indexes :
         txn = self._transaction_begin()
@@ -891,7 +891,7 @@ class BaseGraph(GraphReadWrite):
     def _get(self, txn, key):
         raise NotImplementedError
 
-    def _bulk_get(self, txn, key):
+    def _bulk_get(self, txn, keys):
         raise NotImplementedError
 
     def _set(self, key, value):
@@ -1303,6 +1303,8 @@ class BaseGraph(GraphReadWrite):
 
     def __X(self, _kind, **filters):
 
+        if self._closed:
+            raise GrapheekDataException('Graph is closed')
         if _kind == KIND_VERTEX:
             seq_count = self._node_count
         else:
@@ -1321,9 +1323,13 @@ class BaseGraph(GraphReadWrite):
         return self.__X(KIND_EDGE, **filters)
 
     def v(self, id):
+        if self._closed:  # pragma : no cover
+            raise GrapheekDataException('Graph is closed')
         return Node(id, self)
 
     def e(self, id):
+        if self._closed:  # pragma : no cover
+            raise GrapheekDataException('Graph is closed')
         return Edge(id, self)
 
     def add_node(self, **kwargs):
