@@ -3,7 +3,7 @@
 from types import BooleanType, DictType, FloatType, IntType
 from types import ListType, LongType, NoneType, StringType, TupleType, UnicodeType
 
-import zmq.green as zmq
+import zmq
 import msgpack
 
 from grapheekdb.backends.data.keys import KIND_VERTEX, KIND_EDGE
